@@ -79,6 +79,11 @@ class MetasploitModule < Msf::Exploit::Remote
 
           # Win 8
           ['EDB', '42030'],
+
+          # MITRE ATT&CK
+          ['ATT&CK', Mitre::Attack::Technique::T1059_COMMAND_AND_SCRIPTING_INTERPRETER],
+          ['ATT&CK', Mitre::Attack::Technique::T1068_EXPLOITATION_FOR_PRIVILEGE_ESCALATION],
+          ['ATT&CK', Mitre::Attack::Technique::T1210_EXPLOITATION_OF_REMOTE_SERVICES]
         ],
         'DefaultOptions' => {
           'CheckModule' => 'auxiliary/scanner/smb/smb_ms17_010',
